/* 1) Importer le fichier ’KilledbyUSPolice.xlsx’ sur SAS (PROC IMPORT). */

PROC IMPORT DATAFILE= "/folders/myfolders/KilledbyUSPolice.xlsx"
OUT = WORK.data_TD4
DBMS=XLSX
REPLACE;
RUN;

/* 2) Combien y-a-t-il de variables et d’observations dans le fichier ? 
(PROC CONTENTS ou SUMMARY) */

PROC CONTENTS DATA = WORK.data_TD4; RUN; 

/* 3) Quelles sont les variables numériques ? (PROC CONTENTS) */ 

PROC CONTENTS DATA = WORK.data_TD4; RUN; 

/* 4) On s’intéresse aux variables ’age’, ’p_income’ (revenus de la personne tuée)
et ’h_income’ (revenu médian du ménage de la personne tuée). 
On s’aperçoit que ces variables censées être numériques ont été importées 
en variables textes par SAS. 


4.1) Remplacer les valeurs manquantes symbolisées par ‘NA’ par ’.’ 
(Sans les guillemets pour signaler qu’il s’agit de données manquantes de 
variables numériques) (DATA + SET + Condition). */

DATA WORK.data_TD4;
SET WORK.data_TD4;
IF age = "NA" THEN age = .;
RUN;

DATA WORK.data_TD4;
SET WORK.data_TD4;
IF p_income="NA" THEN p_income = .;
RUN;
	
DATA WORK.data_TD4;
SET WORK.data_TD4;
IF h_income="NA" THEN h_income = .;
RUN;

/* 4.2) Convertir ces variables en variables numériques dans une nouvelle 
colonne (’age_num’, ’p_income_num’ et ’h_income_num’) (DATA + INPUT + FORMAT). */ 

DATA WORK.data_TD4;
  SET WORK.data_TD4;
  age_num=input(age,8.);
RUN;

DATA WORK.data_TD4;
  SET WORK.data_TD4;
  p_income_num=input(p_income,8.);
RUN;

DATA WORK.data_TD4;
  SET WORK.data_TD4;
  h_income_num=input(h_income,8.);
RUN;

/* 4.3) Calculez la moyenne, l’écart type, maximum, minimum des variables 'age_num', 
'p_income_num' et 'h_income_num' et exportez les résultats obtenus dans une sortie 
appelée ’stat1’ (PROC MEANS + OUTPUT OUT). */

PROC MEANS DATA=WORK.data_TD4 mean std min max median Q1 Q3;
VAR age_num p_income_num h_income_num;
OUTPUT OUT = stat1;
RUN;

/* 5) On s’intéresse aux variables ’h_income_num’ et ’county_income’ (revenu 
médian des ménages dans la zone géographique où la personne a été tuée).
Construisez le graphique boxplot de ces deux variables (SGPLOT + option VBOX). */ 

PROC SGPLOT DATA=WORK.data_TD4;
  VBOX h_income_num; 
RUN;

PROC SGPLOT DATA=WORK.data_TD4;
  VBOX county_income; 
RUN;

/* 6) Créez le graphique nuage de points avec en abscisses la variable ’age_num’ 
et en ordonnées ’p_income_num’. Spécifiez un titre pour le graphique. 
Que constatez-vous (SGPLOT + option SCATTER + option TITLE) ? */

PROC SGPLOT data=WORK.data_TD4;
TITLE "Nuage de point age / revenus personnel";
SCATTER x=age_num y=p_income_num;
RUN;

/* 7) Calculez la corrélation entre la variable ’age_num’ et ’p_income_num’. 
Quel est le coefficient de corrélation obtenu ? 
Que pouvez-vous en déduire (PROC CORR) ? */ 

PROC CORR Data = WORK.data_TD4;
Var age_num p_income_num;
RUN;

/* 8) Étude des variables transformées :

8.1) Transformez les variables ’age_num’ et ’p_income_num’ en rang que vous 
nommerez ‘RankAge’ et ‘RankIncome’ (PROC RANK). */

proc rank data=WORK.data_TD4 out=WORK.data_TD4;
   var age_num p_income_num ;
   ranks RankAge RankIncome;
run;

/* 8.2) Croisez les variables ‘RankAge’ et ‘RankIncome’ dans un graphique nuage 
de point. Que constatez-vous ? (SGPLOT + option SCATTER). */

PROC SGPLOT data=WORK.data_TD4;
scatter x=RankAge y=RankIncome;
run;

/* 8.3) Calculez le coefficient de corrélation entre ces deux variables 
transformées. Que constatez-vous ? (PROC CORR) */

proc corr data=classRank PEARSON;
   var RankAge RankIncome;
run;

/* 9) Calculez les coefficients des moindres carrés entre les variables ’age_num’
et ’p_income_num’. Quelle est la valeur du coefficient ? (PROC REG) */

PROC REG data=WORK.data_TD4;
model p_income_num = age_num;
RUN;

/* 10) Tracez la droite de régression entre la variable ’age_num’ et 
’p_income_num’ (PROC SGPLOT + option REG). */

PROC SGPLOT DATA =WORK.data_TD4;
REG x=age_num y=p_income_num;
RUN;



/* Quelques lignes de code qui permettent de faire cette exercice 
	sans avoir réaliser l'exercice 1 */
	
/* Importation des données normalement faites lors de l'exercice 1 */
FILENAME REFFILE '/folders/myfolders/Killed-by-US-Police.xlsx';

PROC IMPORT DATAFILE=REFFILE
	DBMS=XLSX
	OUT=data_TD4;
	GETNAMES=YES;
RUN;


/* Création de la variable 'age_num' normalement crée lors de l'exercice 1 */
data data_TD4;
set data_TD4;
if age="Unknown" then age=.;
age_num=input(age, 8.);
run;



/* Exercice 2 */

/* QUESTION 1 */

/* On remplace les valeurs '.' de age_num par la moyenne de ces valeurs */
/* proc stdize */
proc stdize data=data_TD4 reponly method=mean out=data_TD4;
var age_num;
run;





/* QUESTION 2 */

/* Exploration de 'raceethnicity' */
/* proc freq*/
proc freq data=data_TD4;
tables raceethnicity / plots=(freqplot);
run;





/* QUESTION 3 */

/* On modifie les modalités comportant peu d'individu en 'Other' */
data data_TD4;
length raceethnicity_recode $ 22;
set data_TD4;
select(raceethnicity);
when('Asian/Pacific Islander') raceethnicity_recode='Other';
when('Native American') raceethnicity_recode='Other';
when('Unknown') raceethnicity_recode='Other';
otherwise raceethnicity_recode=raceethnicity;
end;
run;





/* QUESTION 4 ET 5 */

/* Statistiques descriptives sur les 2 variables intéressantes */
proc means data=data_TD4 chartype mean std min max n vardef=df;
var age_num;
class raceethnicity_recode;
run;

proc sort data=data_TD4 out=data_TD4;
	by raceethnicity_recode;
run;

proc boxplot data=data_TD4;
	plot (age_num)*raceethnicity_recode / boxstyle=schematic;
run;


/* QUESTION 6 ET 7 */
/* ANOVA */
proc glm data=data_TD4 plots(only)=(boxplot);
	class raceethnicity_recode;
	model age_num=raceethnicity_recode;
	run;
quit;



/* Exercice 3

 (3.1) Nous souhaitons maintenant regrouper les individus par classe d'âge. Pour cela, nous allons créer une nouvelle variable 'age_recode' */

data data_TD4;
	length age_recode  $7;
	set data_TD4;

	select;
		when (age_num <21) age_recode='mineur';
		when (21 <=age_num <=30) age_recode='jeune adulte';
		when (31 <=age_num <=50) age_recode='adulte';
		when (age_num >=51) age_recode='senior';
		otherwise ;
	end;
run;

/* Représentez graphiquement le nombre d'individus dans les catégories (proc freq). */

proc freq data=data_TD4;
	tables age_recode / plots=(freqplot);
run;

/* (3.2) Faites un tableaux croisés des variables 'age_recode' et 'armed' puis effectuez un test de khi2 entre ces dernières. */

PROC TABULATE
DATA=WORK.data_TD4;
CLASS armed / ORDER=freq;
CLASS age_recode / ORDER=freq;
TABLE
/*Variable en ligne*/
armed=' '
all = 'Total'  ,
/*Variable en colone*/
age_recode =' '
all = 'Total';
;

proc freq DATA=WORK.data_TD4;
TABLE armed*age_recode / chisq expected missing;
run;


/* (3.3) On souhaite étudier les liens entre les variables 'armed' et  'raceethnicity_recode'. Commencez par afficher la fréquence des modalités par variable. */

proc summary data=WORK.data_TD4 nway;
class raceethnicity_recode ;
output out=a (drop=_type_);
run ;

proc summary data=WORK.data_TD4 nway;
class armed ;
output out=b (drop=_type_);
run ;

/* Puis croisez les deux variables dans un tableau, afficher le nombre de modalités ainsi que les profils lignes (ROWPCTN) */

PROC TABULATE
DATA=WORK.data_TD4;
CLASS armed / ORDER=freq;
CLASS raceethnicity_recode / ORDER=freq;
TABLE armed=' '*ROWPCTN all armed=' ' all, raceethnicity_recode all 
;


/* (3.4) Proposez une représentation graphique (mosaicplot) */

proc freq data=WORK.data_TD4;
tables armed*raceethnicity_recode / norow plots=MOSAICPLOT;
run;

/* (3.5) Effectuez un test de khi2. */

proc freq DATA=WORK.data_TD4;
TABLE armed*raceethnicity_recode / chisq expected missing;
run;